import os
from flask import Flask, render_template, request, redirect, session, url_for
import openai

from dotenv import load_dotenv
load_dotenv()   #This method will load variables from .env into the environment

app = Flask(__name__)
app.secret_key = 'sfox1234'

openai_api_key = os.getenv('OPENAI_API_KEY')
if not openai_api_key:
    raise ValueError("No API key found. Please set the OPENAI_API_KEY environment variable in your Heroku config vars.")


@app.route('/', methods=['GET', 'POST'])
def home():
    if request.method == 'POST':
        session['name'] = request.form['name']
        return redirect(url_for('upload'))
    return render_template('index.html')

@app.route('/upload', methods=['GET', 'POST'])
def upload():
    if request.method == 'POST' and openai_api_key:
        description = request.form['description']
        response = openai.ChatCompletion.create(
            model="gpt-4",
            messages=[
                {"role": "user", "content": description}
            ]
        )
        message = response.choices[0]['message']['content']
        return render_template('success.html', message=message)
    elif not openai_api_key:
        return render_template('error.html', error="OpenAI API key is not configured.")
    name = session.get('name', 'Guest')
    return render_template('upload.html', name=name)

@app.route('/success')
def success():
    return render_template('success.html')

